@@ -1,11 +1,9 @@
-import sys
-
 from django.core.management.base import NoArgsCommand
+from django_counter_field.counter import counters
 
-from pomoji.django_counter_field.counter import counters
 
 class Command(NoArgsCommand):
-    help = 'List all registered counters'
+    help = 'List all registered counters.'
 
     def handle(self, **kwargs):
         for i, counter_name in enumerate(counters.keys(), 1):
